/******************************************************************************
*  Title    : LPC17xx Capacitive Touch Sensing demo program
*  Name     : nxp28536
*  Hardware : LPCXpresso 1769 Stick + PCF8883 evaluation kit (sensor)
*
*  1. Use Systick timer to generate a 10 msec timer tick (interrupt driven).
*  2. Capacitive sense plate is connected to digital output / analog input channel
*  3. Every 10 msec: use ADC to read the capacitive sense input.
*
*                  (C) Copyright 2010 NXP Semiconductors
*
*******************************************************************************/

#include "includes.h"  

volatile int cntr = 0;
/* generate a SysTick Timer ISR every 10 msec */
void SysTick_Handler(void)                         
{
    /* iterate through the active channel list to perform readings */
    processChannels();

    /* just simple heartbeat indication, toggle every second */
	cntr++;
	if(cntr == 49) 
	{
        toggleLed();
	    cntr=0;
	}
}


/* main routine */
int main (void)
{
    /* setup the system for clocks etc */
    SystemInit();

    /* convenience debug output on timer0 - match 1	 > DBG LPC6, TP143 */
    /* used to check the clock settings, output is CPU/4 (25 MHz) */
    /* normally commented out */
    #if(0)
	LPC_PINCON->PINSEL3 |= (0x3 << 26);		/* select timer mode  for pin */
	LPC_TIM0->MR1 = 0x1;                    /* count to one for toggling */
	LPC_TIM0->MCR |= (0x1 << 4);            /* reset on match */
	LPC_TIM0->EMR |= (0x3 << 6);            /* toggle on match */
	LPC_TIM0->TCR = 0x1;                    /* start the timer */
    #endif

	
    #ifdef CUSTOM_BOARD
    /* set the port as output and generate external reset for uP */
    LPC_PINCON->PINSEL1 |= (0x1 << 12);
	LPC_GPIO0->FIODIR |= (1<<22);
    LPC_GPIO0->FIOSET |= (1<<22);
    #endif

	/* initialize adc and uart debug output */
    initAdc(SystemFrequency);
    initUart();    /* fixed frequency selected within uart.c module */

    /* initialize led port */
    initLed();

    /* calibrate active channels to setup mean reference value */
    calibrateAllChannels();

    /* config systick to generate interrupts at 100HZ - 10ms rate */
    SysTick_Config(SystemFrequency/100);           

    while (1)
    {
        __wfi();                /* processor goes to sleep in between readings */                      
        processKeystrokes();    /* activate keystroke callbacks if key press detected */

    }
}

