#include <string.h>
#include <LPC17xx.h>
//#include "type.h"
#include "uart.h"

#define IER_RBR		0x01
#define IER_THRE	0x02
#define IER_RLS		0x04

#define IIR_PEND	0x01
#define IIR_RLS		0x03
#define IIR_RDA		0x02
#define IIR_CTI		0x06
#define IIR_THRE	0x01

#define LSR_RDR		0x01
#define LSR_OE		0x02
#define LSR_PE		0x04
#define LSR_FE		0x08
#define LSR_BI		0x10
#define LSR_THRE	0x20
#define LSR_TEMT	0x40
#define LSR_RXFE	0x80

#define BUFSIZE		0x40


volatile uint32_t UART0Status, UART1Status, UART3Status;
volatile uint8_t UART0TxEmpty = 1, UART1TxEmpty = 1, UART3TxEmpty=1;
volatile uint8_t UART0Buffer[BUFSIZE], UART1Buffer[BUFSIZE], UART3Buffer[BUFSIZE];
volatile uint32_t UART0Count = 0, UART1Count = 0, UART3Count = 0;

extern char uartLogBuf[BUFSIZE];



/*****************************************************************************
** Function name:		UARTInit
**
** Descriptions:		Initialize UART port, setup pin select,
**						clock, parity, stop bits, FIFO, etc.
**
** parameters:			portNum(0 or 1) and UART baudrate
** Returned value:		true or false, return false only if the 
**						interrupt handler can't be installed to the 
**						VIC table
** 
*****************************************************************************/

#define UART_9600 		0	
#define UART_115200 	1

/* configure uart debug output */
/* Uart debug tx P0_0 */
void initUart(void)
{
    memset (uartLogBuf,0,BUFSIZE);

    /* RxD3 is P0.1 and TxD3 is P0.0 */
	LPC_PINCON->PINSEL0 &= ~0x0000000F;
	LPC_PINCON->PINSEL0 |=  0x0000000A;  

    LPC_UART3->LCR = 0x83;		/* 8 bits, no Parity, 1 Stop bit */

	if(UART_115200)
	{
	  LPC_UART3->DLM = 0; // for 25MHz, divide by 4, 115200 baud
	  LPC_UART3->DLL = 9;
      LPC_UART3->FDR = ((0x2 << 4)| 0x1); // DIVADDVAL 1, MULVAL 2
	 }

	 if(UART_9600)
	 {
	  LPC_UART3->DLM = 0; // for 25MHz, divide by 4, 9600 baud
	  LPC_UART3->DLL = 108;
      LPC_UART3->FDR = ((0x2 << 4)| 0x1); // DIVADDVAL 1, MULVAL 2

	 }

	  LPC_UART3->LCR = 0x03;		/* DLAB = 0 */
	  LPC_UART3->FCR = 0x07;		/* Enable and reset TX and RX FIFO. */
}

/*****************************************************************************
** Function name:		UARTSend
**
** Descriptions:		Send a block of data to the UART 0 port based
**						on the data length
**
** parameters:			portNum, buffer pointer, and data length
** Returned value:		None
** 
*****************************************************************************/

void sendUart( uint32_t portNum, uint8_t *BufferPtr, uint32_t Length )
{
    uint32_t i;
			
	for(i=0;i<Length;i++)
	{
	    while(!(LPC_UART3->LSR&LSR_THRE));	// Wait for Tx to complete
		LPC_UART3->THR = (*BufferPtr++);
	} 
}

/******************************************************************************
**                            End Of File
******************************************************************************/
